==> vqa-review-embed-1.0.3.tgz: package/webpack.config.js <==
/*
 * Copyright (c) Facebook, Inc. and its affiliates.
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var path = require("path");
var webpack = require("webpack");
const MiniCssExtractPlugin = require('mini-css-extract-plugin');

module.exports = {
  entry: "./src/index.js",
  output: {
    path: __dirname,
    filename: "build/bundle.js",
    library: "VQAReviewEmbed",
    libraryTarget: "umd",
  },
  target: "web",
  externals: {
    react: "react",
    "react-dom": "react-dom",
    // "global-context-store": "global-context-store",
    // "@blueprintjs/core": "@blueprintjs/core",
    // "@blueprintjs/icons": "@blueprintjs/icons",
  },
  optimization: {
    splitChunks: {
      cacheGroups: {
        styles: {
          name: 'styles',
          // type: 'css/mini-extract',
          // For webpack@4
          test: /\.css$/,
          chunks: 'all',
          enforce: true,
        },
      },
    },
  },
  node: {
    net: "empty",
    dns: "empty",
  },
  plugins:[
    new MiniCssExtractPlugin({
        filename: 'build/[name].css',
    }),
  ],
  module: {
    rules: [
      {
        test: /\.(js|jsx)$/,
        loader: "babel-loader",
        exclude: /node_modules/,
        options: { presets: ["@babel/env"] },
      },
      {
        test: /\.*css$/,
        use : [
          MiniCssExtractPlugin.loader,
          'css-loader'
        ]
      },
      {
        test: /\.(jpe?g|png|ttf|eot|svg|woff(2)?)(\?[a-z0-9=&.]+)?$/,
        use: 'base64-inline-loader'
      }
    ],
  },
};

==> vqa-review-embed-1.0.4.tgz: package/webpack.config.js <==
/*
 * Copyright (c) Facebook, Inc. and its affiliates.
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var path = require("path");
var webpack = require("webpack");
const MiniCssExtractPlugin = require('mini-css-extract-plugin');

module.exports = {
  entry: "./src/index.js",
  output: {
    path: __dirname,
    filename: "build/bundle.js",
    library: "VQAReviewEmbed",
    libraryTarget: "umd",
  },
  target: "web",
  externals: {
    // react: "react",
    // "react-dom": "react-dom",
    // "global-context-store": "global-context-store",
    // "@blueprintjs/core": "@blueprintjs/core",
    // "@blueprintjs/icons": "@blueprintjs/icons",
  },
  // optimization: {
  //   splitChunks: {
  //     cacheGroups: {
  //       styles: {
  //         name: 'styles',
  //         // type: 'css/mini-extract',
  //         // For webpack@4
  //         test: /\.css$/,
  //         chunks: 'all',
  //         enforce: true,
  //       },
  //     },
  //   },
  // },
  node: {
    net: "empty",
    dns: "empty",
  },
  plugins:[
    new MiniCssExtractPlugin({
        filename: 'build/[name].css',
    }),
  ],
  module: {
    rules: [
      {
        test: /\.(js|jsx)$/,
        loader: "babel-loader",
        exclude: /node_modules/,
        options: { presets: ["@babel/env"] },
      },
      {
        test: /\.*css$/,
        use : [
          MiniCssExtractPlugin.loader,
          'css-loader'
        ]
      },
      {
        test: /\.(jpe?g|png|ttf|eot|svg|woff(2)?)(\?[a-z0-9=&.]+)?$/,
        use: 'base64-inline-loader'
      }
    ],
  },
};
